@@ -1,5 +1,4 @@
 import numpy as np
-import pandas as pd
 
 import gensim
 from gensim import downloader
@@ -16,18 +15,18 @@ class Vectorizer:
 
     def bert(self, sentences):
         self.sentences = sentences
-        batch = pd.DataFrame(self.sentences)
         model_class, tokenizer_class, pretrained_weights = (ppb.DistilBertModel, ppb.DistilBertTokenizer, 'distilbert-base-uncased')
         tokenizer = tokenizer_class.from_pretrained(pretrained_weights)
         model = model_class.from_pretrained(pretrained_weights)
-        tokenized = batch[0].apply((lambda x: tokenizer.encode(x, add_special_tokens=True)))
+        encoder = lambda x: tokenizer.encode(x, add_special_tokens=True)
+        tokenized = list(map(encoder, sentences))
 
         max_len = 0
-        for i in tokenized.values:
+        for i in tokenized:
             if len(i) > max_len:
                 max_len = len(i)
 
-        padded = np.array([i + [0] * (max_len - len(i)) for i in tokenized.values])
+        padded = np.array([i + [0] * (max_len - len(i)) for i in tokenized])
         attention_mask = np.where(padded != 0, 1, 0)
         input_ids = torch.tensor(np.array(padded)).type(torch.LongTensor)
         attention_mask = torch.tensor(attention_mask).type(torch.LongTensor)
